/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Type;
import org.gnu.glib.Handle;

/**
 *
 */
public class IMMulticontext extends IMContext 
{
	/**
	 * Construct a new IMMulticontext object.
	 */
	public IMMulticontext() {
		super(gtk_im_multicontext_new());
	}
	
	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_im_multicontext_get_type());
	}


    native static final protected int gtk_im_multicontext_get_type ();
    native static final protected Handle gtk_im_multicontext_new ();
    native static final protected void gtk_im_multicontext_append_menuitems (Handle context, Handle menushell);

}

